==> one-9.3.2-en-download.zip: one-9.3.2-en/webhelp/one-webhelp/prf/navig/contents_one.js <==
//
//	FindinSite-CD-JS-HelpIndex database predictdescriptionandgeneration
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var predictdescriptionandgeneration = {
    baseurls: ["../"],
    varname: "predictdescriptionandgeneration",
    tree: [
        { url: "overview.htm", title: "Predict Description and Generation",
          tree: [
              { url: "usage/overview.htm", title: "Predict Description and Generation",
                tree: [
                    { url: "usage/relnotes.htm", title: "Release Notes" },
                    { url: "usage/intro.htm", title: "Introduction" },
                    { url: "usage/elements.htm", title: "Elements of Predict Description and Generation" },
                    { url: "usage/getstart.htm", title: "Getting Started with Predict Description and Generation" },
                    { url: "usage/allobjects.htm", title: "Invoking an Overview of All Documentation Objects" },
                    { url: "usage/natobjects.htm", title: "Managing Natural Objects" },
                    { url: "usage/docobjects.htm", title: "Managing Documentation Objects" },
                    { url: "usage/assolinks.htm", title: "Managing Associations and Links" },
                    { url: "usage/extobjects.htm", title: "Managing External Objects" },
                    { url: "usage/prdcomponents.htm", title: "Managing Predict Components" },
                ]
              },
              { url: "predef/predefover.htm", title: "Predefined Object Types in Predict",
                tree: [
                    { url: "predef/gen.htm", title: "General Information" },
                    { url: "predef/an.htm", title: "Access Definition" },
                    { url: "predef/daover.htm", title: "Database",
                      tree: [
                          { url: "predef/damain.htm", title: "Maintaining Objects of Type Database" },
                          { url: "predef/dadoc.htm", title: "Documenting Databases of Different Types" },
                          { url: "predef/daspec.htm", title: "Database-Specific Maintenance" },
                      ]
                    },
                    { url: "predef/dcover.htm", title: "Dataspace",
                      tree: [
                          { url: "predef/dcmain.htm", title: "Maintaining Objects of Type Dataspace" },
                          { url: "predef/dcspec.htm", title: "Dataspace-Specific Maintenance" },
                      ]
                    },
                    { url: "predef/etover.htm", title: "Extract",
                      tree: [
                          { url: "predef/etmain.htm", title: "Maintaining Objects of Type Extract" },
                      ]
                    },
                    { url: "predef/elover.htm", title: "Field",
                      tree: [
                          { url: "predef/eldefb.htm", title: "Defining Basic Attributes of Fields" },
                          { url: "predef/elderf.htm", title: "Defining Derived Fields" },
                          { url: "predef/elatt.htm", title: "Defining Additional Attributes of Fields" },
                      ]
                    },
                    { url: "predef/fiover.htm", title: "File",
                      tree: [
                          { url: "predef/fimain.htm", title: "Maintaining Objects of Type File" },
                          { url: "predef/fiadabas.htm", title: "Adabas Files, File Type A" },
                          { url: "predef/fift.htm", title: "File Types Conceptual, Standard and Other" },
                          { url: "predef/fisql.htm", title: "SQL File Types" },
                          { url: "predef/fiadsql.htm", title: "Adabas SQL Server" },
                          { url: "predef/fiadad.htm", title: "Adabas D" },
                          { url: "predef/fidb2.htm", title: "DB2" },
                          { url: "predef/fiinfo.htm", title: "Informix" },
                          { url: "predef/fiing.htm", title: "Ingres" },
                          { url: "predef/fiorac.htm", title: "Oracle" },
                          { url: "predef/fisy.htm", title: "Sybase" },
                          { url: "predef/figen.htm", title: "General SQL File, File Type X" },
                          { url: "predef/firdb.htm", title: "RDB" },
                          { url: "predef/fiims.htm", title: "IMS" },
                          { url: "predef/fivsam.htm", title: "VSAM" },
                          { url: "predef/fiisam.htm", title: "ISAM" },
                          { url: "predef/fientsys.htm", title: "Entire System Server" },
                          { url: "predef/fispec.htm", title: "File-Specific Maintenance" },
                          { url: "predef/firipp.htm", title: "Rippling - Ensuring Consistent Data Definitions" },
                      ]
                    },
                    { url: "predef/rl.htm", title: "File Relation" },
                    { url: "predef/ie.htm", title: "Interface" },
                    { url: "predef/kyover.htm", title: "Keyword",
                      tree: [
                          { url: "predef/kymain.htm", title: "Maintaing Objects of Type Keyword" },
                      ]
                    },
                    { url: "predef/ls.htm", title: "Library Structure" },
                    { url: "predef/md.htm", title: "Method" },
                    { url: "predef/nw.htm", title: "Network" },
                    { url: "predef/no.htm", title: "Node" },
                    { url: "predef/pa.htm", title: "Packagelist" },
                    { url: "predef/prover.htm", title: "Program",
                      tree: [
                          { url: "predef/prmain.htm", title: "Maintaining Objects of Type Program" },
                          { url: "predef/praddatt.htm", title: "Defining Additional Attributes of Programs" },
                          { url: "predef/prspec.htm", title: "Program-Specific Maintenance" },
                      ]
                    },
                    { url: "predef/py.htm", title: "Property" },
                    { url: "predef/rt.htm", title: "Report Listing" },
                    { url: "predef/sv.htm", title: "Server" },
                    { url: "predef/scover.htm", title: "Storagespace",
                      tree: [
                          { url: "predef/scmain.htm", title: "Maintaining Objects of Type Storagespace" },
                      ]
                    },
                    { url: "predef/sy.htm", title: "System" },
                    { url: "predef/tr.htm", title: "Trigger" },
                    { url: "predef/usover.htm", title: "User",
                      tree: [
                          { url: "predef/usmain.htm", title: "Maintaining Objects of Type User" },
                      ]
                    },
                    { url: "predef/veover.htm", title: "Verification",
                      tree: [
                          { url: "predef/vemain.htm", title: "Maintaining Objects of Type Verification" },
                          { url: "predef/vespec.htm", title: "Verification-Specific Maintenance" },
                      ]
                    },
                    { url: "predef/vm.htm", title: "Virtual Machine" },
                ]
              },
              { url: "extobjects/extover.htm", title: "External Objects in Predict",
                tree: [
                    { url: "extobjects/intro.htm", title: "Handling of External and Documentation Objects" },
                    { url: "extobjects/gen-over.htm", title: "Generation of External Objects" },
                    { url: "extobjects/gen.htm", title: "About Generation" },
                    { url: "extobjects/genadac.htm", title: "Generate for Adabas - Adabas File" },
                    { url: "extobjects/gennat.htm", title: "Generate for Natural" },
                    { url: "extobjects/gendb2.htm", title: "Generate for DB2" },
                    { url: "extobjects/inc-over.htm", title: "Incorporation" },
                    { url: "extobjects/inc.htm", title: "Concepts of Incorporation" },
                    { url: "extobjects/incadac.htm", title: "Incorporating Adabas Databases" },
                    { url: "extobjects/incadaf.htm", title: "Incorporating Adabas Files" },
                    { url: "extobjects/incdb2common.htm", title: "Common Parameters for All DB2 Types" },
                    { url: "extobjects/incdb2.htm", title: "Incorporating DB2 Storagegroups" },
                    { url: "extobjects/incdb2d.htm", title: "Incorporating DB2 Databases" },
                    { url: "extobjects/incdb2t.htm", title: "Incorporating DB2 Tablespaces and SQL/DS DBspaces" },
                    { url: "extobjects/incdb2q.htm", title: "Incorporating DB2 and SQL/DS Tables/Views" },
                    { url: "extobjects/comp.htm", title: "Concepts of Comparison" },
                    { url: "extobjects/compada.htm", title: "Comparing Adabas Databases" },
                    { url: "extobjects/compadaf.htm", title: "Comparing Adabas Files" },
                    { url: "extobjects/compddm.htm", title: "Comparing DDMs" },
                    { url: "extobjects/compdb2.htm", title: "Comparing DB2 Databases" },
                    { url: "extobjects/compdb2s.htm", title: "Comparing DB2 Storagegroups" },
                    { url: "extobjects/compdb2t.htm", title: "Comparing DB2 Tablespaces" },
                    { url: "extobjects/compdbtv.htm", title: "Comparing DB2 Tables/Views" },
                    { url: "extobjects/adm-over.htm", title: "Administration of External Objects" },
                    { url: "extobjects/prep.htm", title: "Using the Preprocessor" },
                    { url: "extobjects/prepstat.htm", title: "Preprocessor Statements" },
                    { url: "extobjects/prepxref.htm", title: "Creation of XRef Data" },
                ]
              },
          ]
  },
  ]
};

var mainProject = 0;

$.event.trigger({ type: "fishidbloaded", db: predictdescriptionandgeneration });

==> one-9.3.3-en-download.zip: one-9.3.3-en/webhelp/one-webhelp/prf/navig/contents_one.js <==
//
//	FindinSite-CD-JS-HelpIndex database predictdescriptionandgeneration
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var predictdescriptionandgeneration = {
    baseurls: ["../"],
    varname: "predictdescriptionandgeneration",
    tree: [
        { url: "overview.htm", title: "Predict Description and Generation",
          tree: [
              { url: "usage/overview.htm", title: "Predict Description and Generation",
                tree: [
                    { url: "usage/relnotes.htm", title: "Release Notes" },
                    { url: "usage/intro.htm", title: "Introduction" },
                    { url: "usage/elements.htm", title: "Elements of Predict Description and Generation" },
                    { url: "usage/getstart.htm", title: "Getting Started with Predict Description and Generation" },
                    { url: "usage/allobjects.htm", title: "Invoking an Overview of All Documentation Objects" },
                    { url: "usage/natobjects.htm", title: "Managing Natural Objects" },
                    { url: "usage/docobjects.htm", title: "Managing Documentation Objects" },
                    { url: "usage/assolinks.htm", title: "Managing Associations and Links" },
                    { url: "usage/extobjects.htm", title: "Managing External Objects" },
                    { url: "usage/prdcomponents.htm", title: "Managing Predict Components" },
                ]
              },
              { url: "predef/predefover.htm", title: "Predefined Object Types in Predict",
                tree: [
                    { url: "predef/gen.htm", title: "General Information" },
                    { url: "predef/an.htm", title: "Access Definition" },
                    { url: "predef/daover.htm", title: "Database",
                      tree: [
                          { url: "predef/damain.htm", title: "Maintaining Objects of Type Database" },
                          { url: "predef/dadoc.htm", title: "Documenting Databases of Different Types" },
                          { url: "predef/daspec.htm", title: "Database-Specific Maintenance" },
                      ]
                    },
                    { url: "predef/dcover.htm", title: "Dataspace",
                      tree: [
                          { url: "predef/dcmain.htm", title: "Maintaining Objects of Type Dataspace" },
                          { url: "predef/dcspec.htm", title: "Dataspace-Specific Maintenance" },
                      ]
                    },
                    { url: "predef/etover.htm", title: "Extract",
                      tree: [
                          { url: "predef/etmain.htm", title: "Maintaining Objects of Type Extract" },
                      ]
                    },
                    { url: "predef/elover.htm", title: "Field",
                      tree: [
                          { url: "predef/eldefb.htm", title: "Defining Basic Attributes of Fields" },
                          { url: "predef/elderf.htm", title: "Defining Derived Fields" },
                          { url: "predef/elatt.htm", title: "Defining Additional Attributes of Fields" },
                      ]
                    },
                    { url: "predef/fiover.htm", title: "File",
                      tree: [
                          { url: "predef/fimain.htm", title: "Maintaining Objects of Type File" },
                          { url: "predef/fiadabas.htm", title: "Adabas Files, File Type A" },
                          { url: "predef/fift.htm", title: "File Types Conceptual, Standard and Other" },
                          { url: "predef/fisql.htm", title: "SQL File Types" },
                          { url: "predef/fiadsql.htm", title: "Adabas SQL Server" },
                          { url: "predef/fiadad.htm", title: "Adabas D" },
                          { url: "predef/fidb2.htm", title: "DB2" },
                          { url: "predef/fiinfo.htm", title: "Informix" },
                          { url: "predef/fiing.htm", title: "Ingres" },
                          { url: "predef/fiorac.htm", title: "Oracle" },
                          { url: "predef/fisy.htm", title: "Sybase" },
                          { url: "predef/figen.htm", title: "General SQL File, File Type X" },
                          { url: "predef/firdb.htm", title: "RDB" },
                          { url: "predef/fiims.htm", title: "IMS" },
                          { url: "predef/fivsam.htm", title: "VSAM" },
                          { url: "predef/fiisam.htm", title: "ISAM" },
                          { url: "predef/fientsys.htm", title: "Entire System Server" },
                          { url: "predef/fispec.htm", title: "File-Specific Maintenance" },
                          { url: "predef/firipp.htm", title: "Rippling - Ensuring Consistent Data Definitions" },
                      ]
                    },
                    { url: "predef/rl.htm", title: "File Relation" },
                    { url: "predef/ie.htm", title: "Interface" },
                    { url: "predef/kyover.htm", title: "Keyword",
                      tree: [
                          { url: "predef/kymain.htm", title: "Maintaining Objects of Type Keyword" },
                      ]
                    },
                    { url: "predef/ls.htm", title: "Library Structure" },
                    { url: "predef/md.htm", title: "Method" },
                    { url: "predef/nw.htm", title: "Network" },
                    { url: "predef/no.htm", title: "Node" },
                    { url: "predef/pa.htm", title: "Packagelist" },
                    { url: "predef/prover.htm", title: "Program",
                      tree: [
                          { url: "predef/prmain.htm", title: "Maintaining Objects of Type Program" },
                          { url: "predef/praddatt.htm", title: "Defining Additional Attributes of Programs" },
                          { url: "predef/prspec.htm", title: "Program-Specific Maintenance" },
                      ]
                    },
                    { url: "predef/py.htm", title: "Property" },
                    { url: "predef/rt.htm", title: "Report Listing" },
                    { url: "predef/sv.htm", title: "Server" },
                    { url: "predef/scover.htm", title: "Storagespace",
                      tree: [
                          { url: "predef/scmain.htm", title: "Maintaining Objects of Type Storagespace" },
                      ]
                    },
                    { url: "predef/sy.htm", title: "System" },
                    { url: "predef/tr.htm", title: "Trigger" },
                    { url: "predef/usover.htm", title: "User",
                      tree: [
                          { url: "predef/usmain.htm", title: "Maintaining Objects of Type User" },
                      ]
                    },
                    { url: "predef/veover.htm", title: "Verification",
                      tree: [
                          { url: "predef/vemain.htm", title: "Maintaining Objects of Type Verification" },
                          { url: "predef/vespec.htm", title: "Verification-Specific Maintenance" },
                      ]
                    },
                    { url: "predef/vm.htm", title: "Virtual Machine" },
                ]
              },
              { url: "extobjects/extover.htm", title: "External Objects in Predict",
                tree: [
                    { url: "extobjects/intro.htm", title: "Handling of External and Documentation Objects" },
                    { url: "extobjects/gen-over.htm", title: "Generation of External Objects",
                      tree: [
                          { url: "extobjects/gen.htm", title: "About Generation" },
                          { url: "extobjects/genadac.htm", title: "Generate for Adabas - Adabas File" },
                          { url: "extobjects/gennat.htm", title: "Generate for Natural" },
                          { url: "extobjects/gendb2.htm", title: "Generate for DB2" },
                      ]
                    },
                    { url: "extobjects/inc-over.htm", title: "Incorporation",
                      tree: [
                          { url: "extobjects/inc.htm", title: "Concepts of Incorporation" },
                          { url: "extobjects/incadac.htm", title: "Incorporating Adabas Databases" },
                          { url: "extobjects/incadaf.htm", title: "Incorporating Adabas Files" },
                          { url: "extobjects/incdb2common.htm", title: "Common Parameters for All DB2 Types" },
                          { url: "extobjects/incdb2.htm", title: "Incorporating DB2 Storagegroups" },
                          { url: "extobjects/incdb2d.htm", title: "Incorporating DB2 Databases" },
                          { url: "extobjects/incdb2t.htm", title: "Incorporating DB2 Tablespaces and SQL/DS DBspaces" },
                          { url: "extobjects/incdb2q.htm", title: "Incorporating DB2 and SQL/DS Tables/Views" },
                      ]
                    },
                    { url: "extobjects/adm-over.htm", title: "Administration of External Objects" },
                ]
              },
          ]
  },
  ]
};

var mainProject = 0;

$.event.trigger({ type: "fishidbloaded", db: predictdescriptionandgeneration });
